@@ -83,7 +83,7 @@ r"""
    ⋅- [H] flags:
    ⋅
    ⋅    A flag is a tag already defined (see [I] section).
-é   ⋅
+   ⋅
    ⋅    :flag:          🏴‍☠️ : pirate  # the meaning of 🏴‍☠️ is 'pirate'
    ⋅
    ⋅                           Beware, don't add a comment at the end of a line !
@@ -975,7 +975,7 @@ class ETR:
         if source_filename in self._nested_files:
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID002"
-            error.msg = "Cyclic import in '{source_filename}' ." \
+            error.msg = f"Cyclic import in '{source_filename}' ." \
                 f"Parent files already read are f{self._nested_files}"
             self.errors.append(error)
             yield from self._read_action(TLFF(line_inttype=ETRLINE_INTTYPE__NONE))
@@ -988,7 +988,7 @@ class ETR:
         if not os.path.exists(source_filename):
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID000"
-            error.msg = "Missing ETR MusaMusa text file '{source_filename}' ."
+            error.msg = f"Missing ETR MusaMusa text file '{source_filename}' ."
             self.errors.append(error)
             yield from self._read_action(TLFF(line_inttype=ETRLINE_INTTYPE__NONE))
             return
